==> vue-components-1.5.13.tgz: package/lib/fileUpload/src/ShowFileItem.vue.rd.js <==
import { useInjectStyle as z } from "../../shared/hooks/useInjectStyle.rd.js";
import { defineComponent as k, ref as I, computed as _, onMounted as S, openBlock as a, createElementBlock as $, normalizeClass as C, unref as e, createBlock as d, mergeProps as N, withCtx as h, createElementVNode as t, createVNode as F, toDisplayString as s, createTextVNode as f, createCommentVNode as P } from "vue";
import { useFileMeta as T } from "@regiondev/vue-hooks";
import { readImageAsUrl as V } from "@regiondev/vue-utils";
import "../../fileType/index.rd.js";
import "../../popover/index.rd.js";
import j from "./ImagePreview.vue.rd.js";
import { showFileItemProps as B } from "./props.rd.js";
import E from "./showFileItem.scss.rd.js";
import M from "../../popover/src/Popover.vue.rd.js";
import x from "../../fileType/src/FileType.vue.rd.js";
const A = { class: "flex popover-file-icon" }, D = { class: "flex flex-col truncate justify-start ml-3 min-w-200px" }, L = ["title"], R = { class: "text-muted" }, U = /* @__PURE__ */ t("span", { class: "font-bold" }, "Size:", -1), q = { class: "text-muted" }, G = /* @__PURE__ */ t("span", { class: "font-bold" }, "Type:", -1), H = { class: "text-muted" }, J = /* @__PURE__ */ t("span", { class: "font-bold" }, "Last modified:", -1), K = { class: "py-3 px-4 w-full flex" }, O = /* @__PURE__ */ t("span", { class: "i-heroicons-outline:x" }, null, -1), Q = [
  O
], W = { class: "flex flex-col truncate justify-start ml-3" }, X = { class: "truncate text-theme mb-0 text-sm font-bold" }, Y = { class: "text-muted" }, fe = /* @__PURE__ */ k({
  __name: "ShowFileItem",
  props: B(),
  emits: ["remove"],
  setup(v, { emit: Z }) {
    const i = v;
    z(E, "show-file-icon");
    const p = I(""), { fileExt: u, fileSizeStr: m, lastModified: y, metatype: c, name: l, size: ee, type: b } = T(i.file), n = _(() => i.showImagePreview && c == "image");
    S(() => {
      n.value && V(i.file, (o) => {
        o.result && (p.value = o.result);
      });
    });
    const g = _(() => i.showPopoverInfo ? {} : { visible: !1 });
    return (o, r) => (a(), $("div", {
      class: C(["dark:bg-slate-800 file-item flex flex-row overflow-hidden group bg-slate-200 relative round animated !animate-duration-200", {
        "animate-zoom-in hover:bg-slate-300 dark:hover:bg-slate-700": !e(n),
        "animate-fade-in": e(n)
      }])
    }, [
      e(n) ? (a(), d(j, {
        key: 0,
        src: e(p),
        name: e(l),
        "file-size": e(m),
        onRemove: r[0] || (r[0] = (w) => o.$emit("remove"))
      }, null, 8, ["src", "name", "file-size"])) : (a(), d(e(M), N({ key: 1 }, e(g), {
        overlayClassName: "max-w-300px",
        title: null
      }), {
        content: h(() => [
          t("div", A, [
            F(e(x), {
              type: e(c),
              extension: e(u),
              size: "md"
            }, null, 8, ["type", "extension"]),
            t("div", D, [
              t("h3", {
                title: e(l),
                class: "mb-0 text-theme truncate font-bold mb-2"
              }, s(e(l)), 9, L),
              t("small", R, [
                U,
                f(" " + s(e(m)), 1)
              ]),
              t("small", q, [
                G,
                f(" " + s(e(b)), 1)
              ]),
              t("small", H, [
                J,
                f(" " + s(e(y)), 1)
              ])
            ])
          ])
        ]),
        default: h(() => [
          t("div", K, [
            t("button", {
              class: "btn-circle absolute right-2 !p-0.5 opacity-0 group-hover:opacity-90 border-solid top-2",
              onClick: r[1] || (r[1] = (w) => o.$emit("remove"))
            }, Q),
            o.showFileTypeIcon ? (a(), d(e(x), {
              key: 0,
              type: e(c),
              extension: e(u),
              size: o.fileTypeIconSize
            }, null, 8, ["type", "extension", "size"])) : P("", !0),
            t("div", W, [
              t("h3", X, s(e(l)), 1),
              t("small", Y, s(e(m)), 1)
            ])
          ])
        ]),
        _: 1
      }, 16))
    ], 2));
  }
});
export {
  fe as default
};

==> vue-components-1.5.43.tgz: package/lib/fileUpload/src/ShowFileItem.vue.rd.js <==
import { useInjectStyle as z } from "../../shared/hooks/useInjectStyle.rd.js";
import { defineComponent as S, ref as k, computed as _, onMounted as I, openBlock as a, createElementBlock as $, normalizeClass as C, unref as e, createBlock as d, mergeProps as N, withCtx as h, createElementVNode as t, createVNode as F, toDisplayString as s, createTextVNode as f, createCommentVNode as P } from "vue";
import { useFileMeta as T } from "@regiondev/vue-hooks";
import { readImageAsUrl as V } from "@regiondev/vue-utils";
import "../../fileType/index.rd.js";
import "../../popover/index.rd.js";
import j from "./ImagePreview.vue.rd.js";
import { showFileItemProps as B } from "./props.rd.js";
import E from "./showFileItem.scss.rd.js";
import M from "../../popover/src/Popover.vue.rd.js";
import x from "../../fileType/src/FileType.vue.rd.js";
const A = { class: "flex popover-file-icon" }, D = { class: "flex flex-col truncate justify-start ml-3 min-w-200px" }, L = ["title"], R = { class: "text-muted" }, U = /* @__PURE__ */ t("span", { class: "font-bold" }, "Size:", -1), q = { class: "text-muted" }, G = /* @__PURE__ */ t("span", { class: "font-bold" }, "Type:", -1), H = { class: "text-muted" }, J = /* @__PURE__ */ t("span", { class: "font-bold" }, "Last modified:", -1), K = { class: "py-3 px-4 w-full flex" }, O = /* @__PURE__ */ t("span", { class: "i-heroicons-outline:x" }, null, -1), Q = [
  O
], W = { class: "flex flex-col truncate justify-start ml-3" }, X = { class: "truncate text-theme mb-0 text-sm font-bold" }, Y = { class: "text-muted" }, fe = /* @__PURE__ */ S({
  __name: "ShowFileItem",
  props: B(),
  emits: ["remove"],
  setup(v, { emit: Z }) {
    const i = v;
    z(E, "show-file-icon");
    const p = k(""), { fileExt: u, fileSizeStr: m, lastModified: y, metatype: c, name: l, size: ee, type: b } = T(i.file), n = _(() => i.showImagePreview && c == "image");
    I(() => {
      n.value && V(i.file, (o) => {
        o.result && (p.value = o.result);
      });
    });
    const g = _(() => i.showPopoverInfo ? {} : { visible: !1 });
    return (o, r) => (a(), $("div", {
      class: C(["dark:!bg-rdSurface-800 file-item flex flex-row overflow-hidden group bg-rdSurface-200 relative round animated !animate-duration-200", {
        "animate-zoom-in hover:bg-rdSurface-300 dark:hover:!bg-rdSurface-700": !e(n),
        "animate-fade-in": e(n)
      }])
    }, [
      e(n) ? (a(), d(j, {
        key: 0,
        src: e(p),
        name: e(l),
        "file-size": e(m),
        onRemove: r[0] || (r[0] = (w) => o.$emit("remove"))
      }, null, 8, ["src", "name", "file-size"])) : (a(), d(e(M), N({ key: 1 }, e(g), {
        overlayClassName: "max-w-300px",
        title: null
      }), {
        content: h(() => [
          t("div", A, [
            F(e(x), {
              type: e(c),
              extension: e(u),
              size: "md"
            }, null, 8, ["type", "extension"]),
            t("div", D, [
              t("h3", {
                title: e(l),
                class: "mb-0 text-theme truncate font-bold mb-2"
              }, s(e(l)), 9, L),
              t("small", R, [
                U,
                f(" " + s(e(m)), 1)
              ]),
              t("small", q, [
                G,
                f(" " + s(e(b)), 1)
              ]),
              t("small", H, [
                J,
                f(" " + s(e(y)), 1)
              ])
            ])
          ])
        ]),
        default: h(() => [
          t("div", K, [
            t("button", {
              class: "btn-circle absolute right-2 !p-0.5 opacity-0 group-hover:opacity-90 border-solid top-2",
              onClick: r[1] || (r[1] = (w) => o.$emit("remove"))
            }, Q),
            o.showFileTypeIcon ? (a(), d(e(x), {
              key: 0,
              type: e(c),
              extension: e(u),
              size: o.fileTypeIconSize
            }, null, 8, ["type", "extension", "size"])) : P("", !0),
            t("div", W, [
              t("h3", X, s(e(l)), 1),
              t("small", Y, s(e(m)), 1)
            ])
          ])
        ]),
        _: 1
      }, 16))
    ], 2));
  }
});
export {
  fe as default
};
